package cn.com.infosec.asn1;

import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.math.BigInteger;

public class DERObjectIdentifier extends ASN1Object {
   String identifier;

   public static DERObjectIdentifier getInstance(Object obj) {
      if (obj != null && !(obj instanceof DERObjectIdentifier)) {
         throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
      } else {
         return (DERObjectIdentifier)obj;
      }
   }

   public static DERObjectIdentifier getInstance(ASN1TaggedObject obj, boolean explicit) {
      boolean var10000 = explicit;
      DERObject explicit1 = obj.getObject();
      return (DERObjectIdentifier)(!var10000 && !(explicit1 instanceof DERObjectIdentifier) ? new ASN1ObjectIdentifier(ASN1OctetString.getInstance(obj.getObject()).getOctets()) : getInstance(explicit1));
   }

   DERObjectIdentifier(byte[] bytes) {
      StringBuffer var2;
      var2 = new StringBuffer.<init>();
      long var3 = 0L;
      BigInteger var5 = null;
      boolean var6 = true;

      for(int var7 = 0; var7 != bytes.length; ++var7) {
         int var8 = bytes[var7] & 255;
         if (var3 < 36028797018963968L) {
            var3 = var3 * 128L + (long)(var8 & 127);
            if ((var8 & 128) == 0) {
               if (var6) {
                  int var9;
                  if ((var9 = (int)var3 / 40) != 0) {
                     if (var9 != 1) {
                        var2.append('2');
                        var3 -= 80L;
                     } else {
                        var2.append('1');
                        var3 -= 40L;
                     }
                  } else {
                     var2.append('0');
                  }

                  var6 = false;
               }

               var2.append('.');
               var2.append(var3);
               var3 = 0L;
            }
         } else {
            if (var5 == null) {
               var5 = BigInteger.valueOf(var3);
            }

            var5 = var5.shiftLeft(7).or(BigInteger.valueOf((long)(var8 & 127)));
            if ((var8 & 128) == 0) {
               var2.append('.');
               var2.append(var5);
               var5 = null;
               var3 = 0L;
            }
         }
      }

      this.identifier = var2.toString();
   }

   public DERObjectIdentifier(String identifier) {
      if (isValidIdentifier(identifier)) {
         this.identifier = identifier;
      } else {
         throw new IllegalArgumentException("string " + identifier + " not an OID");
      }
   }

   private void writeField(OutputStream out, long fieldValue) {
      byte[] var5;
      byte[] var10000 = var5 = new byte[9];
      int var4 = 8;

      for(var10000[8] = (byte)((int)fieldValue & 127); fieldValue >= 128L; var5[var4 += -1] = (byte)((int)fieldValue & 127 | 128)) {
         fieldValue >>= 7;
      }

      OutputStream var7 = out;
      int out1 = 9 - var4;
      var7.write(var5, var4, out1);
   }

   private void writeField(OutputStream out, BigInteger fieldValue) {
      int var5;
      if ((var5 = (fieldValue.bitLength() + 6) / 7) == 0) {
         out.write(0);
      } else {
         byte[] var6 = new byte[var5];
         int var3 = var5 - 1;

         for(int var4 = var3; var4 >= 0; --var4) {
            var6[var4] = (byte)(fieldValue.intValue() & 127 | 128);
            fieldValue = fieldValue.shiftRight(7);
         }

         var6[var3] = (byte)(var6[var3] & 127);
         out.write(var6);
      }

   }

   private static boolean isValidIdentifier(String identifier) {
      if (identifier.length() >= 3 && identifier.charAt(1) == '.') {
         char var1;
         if ((var1 = identifier.charAt(0)) >= '0' && var1 <= '2') {
            boolean var4 = false;

            for(int var2 = identifier.length() - 1; var2 >= 2; --var2) {
               char var3 = identifier.charAt(var2);
               if ('0' <= var3 && var3 <= '9') {
                  var4 = true;
               } else {
                  if (var3 != '.') {
                     return false;
                  }

                  if (!var4) {
                     return false;
                  }

                  var4 = false;
               }
            }

            return var4;
         } else {
            return false;
         }
      } else {
         return false;
      }
   }

   public String getId() {
      return this.identifier;
   }

   void encode(DEROutputStream out) {
      OIDTokenizer var2;
      var2 = new OIDTokenizer.<init>(this.identifier);
      ByteArrayOutputStream var3;
      ByteArrayOutputStream var10001 = var3 = new ByteArrayOutputStream;
      var3.<init>();
      DEROutputStream var4;
      var4 = new DEROutputStream.<init>(var3);
      this.writeField(var10001, (long)(Integer.parseInt(var2.nextToken()) * 40 + Integer.parseInt(var2.nextToken())));

      while(var2.hasMoreTokens()) {
         String var5;
         if ((var5 = var2.nextToken()).length() < 18) {
            long var7 = Long.parseLong(var5);
            this.writeField(var3, var7);
         } else {
            BigInteger var6;
            var6 = new BigInteger.<init>(var5);
            this.writeField(var3, var6);
         }
      }

      var4.close();
      out.writeEncoded(6, var3.toByteArray());
   }

   public int hashCode() {
      return this.identifier.hashCode();
   }

   boolean asn1Equals(DERObject o) {
      return !(o instanceof DERObjectIdentifier) ? false : this.identifier.equals(((DERObjectIdentifier)o).identifier);
   }

   public String toString() {
      return this.getId();
   }
}
